# Copyright (C) 2006-2012 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

from agent.base import Agent


class Cluster(Agent):
    """
    Class for cluster management.
    """

    def configure_server_for_cluster(self, o2cb_conf, cluster_conf,
                poolfs_type, poolfs_target, poolfs_uuid, poolfs_nfsbase_uuid):
        """
        Configures the server for the cluster.

        @param o2cb_conf: system parameters for the cluster
        @type  o2cb_conf: C{dict}
        
        @param cluster_conf: the cluster configuration
        @type  cluster_conf: C{str}
        
        @param poolfs_type: type of the pool filesystem, either C{'nfs'}
        or C{'lun'}
        @type  poolfs_type: C{str}
        
        @param poolfs_target: physical location of the pool filesystem
        @type  poolfs_target: C{str}
        
        @param poolfs_uuid: a unique identifier for the pool filesystem
        @type  poolfs_uuid: C{str}
        
        @param poolfs_nfsbase_uuid: a unique identifier for the base NFS
        filesystem
        @type  poolfs_nfsbase_uuid: C{str}

        @raise IModuleException: on failure
        
        """
        raise NotImplementedError()

    def deconfigure_server_for_cluster(self, poolfs_uuid):
        """
        Removes the cluster configuration.

        @param poolfs_uuid: a unique identifier for the pool filesystem
        @type  poolfs_uuid: C{str}
        
        @raise IModuleException: on failure

        """
        raise NotImplementedError()

    def update_cluster_configuration(self, cluster_conf):
        """
        Updates the cluster configuration.

        @param cluster_conf: the cluster configuration
        @type  cluster_conf: C{str}

        @raise IModuleException: on failure

        """
        raise NotImplementedError()

    def create_cluster(self, poolfs_uuid):
        """
        Creates a new cluster and add this server to the cluster.

        @param poolfs_uuid: pool filesystem uuid
        @type  poolfs_uuid: C{str}
        
        @raise IModuleException: on failure

        """
        raise NotImplementedError()

    def join_cluster(self, poolfs_uuid):
        """
        Add this server to an existing cluster.

        @param poolfs_uuid: pool filesystem uuid
        @type  poolfs_uuid: C{str}

        @raise IModuleException: on failure

        """
        raise NotImplementedError()

    def destroy_cluster(self, poolfs_uuid, force=False):
        """
        Destroy the cluster.
        
        @param poolfs_uuid: pool filesystem uuid
        @type  poolfs_uuid: C{str}

        @raise IModuleException: on failure

        """
        raise NotImplementedError()

    def leave_cluster(self, poolfs_uuid, force=False):
        """
        Removes this server from the cluster.

        @param poolfs_uuid: pool filesystem uuid
        @type  poolfs_uuid: C{str}

        @raise IModuleException: on failure

        """
        raise NotImplementedError()

    def is_cluster_online(self):
        """
        Indicate if the cluster is online or not.

        @return: C{True} if the cluster is online, C{False} otherwise.
        @rtype: C{bool}
        
        """
        raise NotImplementedError()

    def discover_cluster(self):
        """
        Discover information about the cluster configured for this server.

        @return: Returns the discovery data as an XML document
        @rtype: C{str}
        
        @raise IModuleException: on failure

        """
        raise NotImplementedError()
