# Copyright (C) 2006-2011 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

import errno
import glob
import logging
import os
import resource
import signal
import sys
from agent.common import run_cmd, old_run_cmd


def write_pidfile(pidfile):
    flags = (os.O_CREAT | os.O_EXCL | os.O_WRONLY)
    mode = (((os.R_OK | os.W_OK) << 6) | ((os.R_OK) << 3) | ((os.R_OK)))
    fd = os.open(pidfile, flags, mode)
    f = os.fdopen(fd, 'w')
    f.write('%d\n' % os.getpid())
    f.close()


def delete_pidfile(pidfile):
    try:
        os.unlink(pidfile)
    except OSError, err:
        if err.errno == errno.ENOENT:
            pass
        else:
            raise


def get_processes_children(pid_list):
    try:
        cmd = 'pgrep -P %s' % ','.join(pid_list)
        return old_run_cmd(cmd).splitlines()
    except Exception:
        return []


def get_agent_process():
    result = []
    pidfile_list = glob.glob('/var/run/ovs-agent/*.pid')
    for pidfile in pidfile_list:
        pname = os.path.basename(pidfile)[:-4] # remove trailing '.pid'
        f = open(pidfile)
        pid = f.read().strip()
        f.close()
        result.append((pname, pid, pidfile))
    return result


def reload_server(name):
    pidfile = ('/var/run/ovs-agent/%s.pid' % name)
    try:
        if os.path.exists(pidfile):
            f = open(pidfile)
            pid = f.read().strip()
            f.close()
            os.kill(int(pid), signal.SIGUSR1)
    except Exception, err:
        logging.warn('Cannot reload server %s: %s', name, err)


def reload_notification_server():
    reload_server('notification')


def reload_xmlrpc_server():
    reload_server('xmlrpc')


def reload_ovm_consoled():
    run_cmd(['service', 'ovm-consoled', 'restart'])


def clean_up_lock():
    for lockfile in glob.glob('/var/run/ovs-agent/*.lock'):
        os.unlink(lockfile)


def run_service(name, func):
    pid = os.fork()
    if pid:
        return

    pid = os.fork()
    if pid:
        os._exit(0)

    os.chdir('/')
    os.setsid()
    os.umask(0077)

    os.close(0)
    os.close(1)
    os.close(2)
    os.open(os.devnull, os.O_RDWR)
    os.dup2(0, 1)
    os.dup2(0, 2)

    pidfile = '/var/run/ovs-agent/%s.pid' % name
    write_pidfile(pidfile)

    try:
        func()
    except Exception, err:
        logging.exception('Error starting %s server: %s', name, err)
