# Copyright (C) 2006-2011 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

from agent.base import Agent


class Host(Agent):
    """
    Class for host management.
    """

    def get_yum_config(self):
        raise NotImplementedError()

    def configure_yum(self, section, params):
        raise NotImplementedError()

    def delete_yum_repo(self, repo_id):
        raise NotImplementedError()

    def yum_list_package(self, pkgnarrow='all', patterns=None, showdups=None, ignore_case=False):
        raise NotImplementedError()

    def yum_update(self, option=''):
        raise NotImplementedError()

    def list_package(self, name='*'):
        raise NotImplementedError()

    def install_package(self, pkg_data, option=''):
        raise NotImplementedError()

    def uninstall_package(self, pkg_list, option=''):
        raise NotImplementedError()

    def get_datetime(self):
        raise NotImplementedError()

    def set_datetime(self, year, month, day, hour, min, sec):
        raise NotImplementedError()

    def get_timezone(self):
        raise NotImplementedError()

    def set_timezone(self, timezone, utc=False):
        raise NotImplementedError()

    def get_ntp(self):
        raise NotImplementedError()

    def set_ntp(self, servers, local_time_source=False, allow_query=False):
        raise NotImplementedError()

    def enable_ntp(self):
        raise NotImplementedError()

    def disable_ntp(self):
        raise NotImplementedError()

    def get_log(self, loglist=None):
        raise NotImplementedError()

    def get_support_files(self):
        raise NotImplementedError()

    def update_agent_password(self, username, password):
        raise NotImplementedError()

    def update_core_api_bindings(self, url, option=None):
        raise NotImplementedError()

    def discover_server(self):
        """
        Discover the identity, version and other properties of the server.

        @return     Discovery data as an XML document.
                    Raises an exception on failure.
        """
        raise NotImplementedError()

    def discover_hardware(self):
        """
        Discover information about the hardware present on this server.
        This includes CPU, I/O Adapters, Memory, and BIOS info.
        No information about storage devices is returned.

        @return    Returns the discovery data as an XML document.
                   Raises an exceptionon failure.
        """
        raise NotImplementedError()

    def copy_file(self, src, dst, sparse=True, update_period=20):
        """
        Copy src to dst with O_DIRECT.  Either may be a file or a block device.

        @return: Dict of function name to function mappings.
        @rtype: C{dict}
        """
        raise NotImplementedError()

    def ovs_download_file(self, url, filename, option=None, obj='file', obj_current=1,
                  obj_total=1, update_period=20):
        """
        Download file from URL.

        @return: Dict of function name to function mappings.
        @rtype: C{dict}
        """
        raise NotImplementedError()

    def ovs_async_proc(self, func, *args):
        """
        Runs func as a daemon, add it PID to the process DB table (aproc)

        @param func    The function to run
        @param args    A list of arguments to pass to the function

        @return        If successful, returns the process ID.
                       Raises an exception on failure.

        Restriction:
            The function must be known to OVSServices, otherwise this call will fail.
        """
        raise NotImplementedError()

    def ovs_async_proc_status(self, pid):
        """
        Gets the running status of a daemon as defined by the Linux kernel

        @param pid     Process ID

        @return        If successful, returns procesess running status
                       Raises an exception on failure.
        Restriction:
           - PID must exists in the process DB table (aproc)
        """
        raise NotImplementedError()

    def ovs_async_proc_signal(self, sig, pid):
        """
        Sends SIGKILL, SIGUSR1 to a running process

        @param sig     (kill | stop)
                       kill: sends a SIGKILL to the process
                       stop: sends a SIGUSR1 to the process
        @param pid     Process ID to signal

        @return        If successful, returns procesess ID, and signal delivered
                       Raises an exception on failure.

        Restriction:
           - For a process to receive SIGUSR1, a processes must register a
             signal handler. The purpose of this signal is to tell the process
             to clean up and exit vs just killing it.
           - PID must exists in the process DB table (aproc)
        """
        raise NotImplementedError()

    def discover_mounted_file_systems(self, args):
        """
        Get the mounted type file systems.

        Returns an empty document if the server is unassociated.

        @param      None

        @return     Returns the discovery data as an XML document.
                    Raises an exception on failure
        """
        raise NotImplementedError()

    def get_last_boot_time(self):
        raise NotImplementedError()

    def get_services(self):
        raise NotImplementedError()
