# Copyright (C) 2006-2011 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

import logging
import time
from agent.constants import *
from agent.config import get_config
from agent.db import read_item, write_item
from agent.notification import notify_manager
from agent.serverpool import get_cluster_state


def serve_forever():
    logging.info("MONITOR SERVER STARTED")
    config = get_config()
    monitor_interval = int(config.get("monitor", "interval"))
    write_item(LOCAL_SERVER_DB, "cluster_state", STATE_UNKNOWN)
    while True:
        try:
            time.sleep(monitor_interval)
            saved_cluster_state = read_item(LOCAL_SERVER_DB, "cluster_state")
            saved_cluster_state = saved_cluster_state or STATE_UNKNOWN
            current_cluster_state = get_cluster_state()
            if saved_cluster_state != current_cluster_state:
                write_item(LOCAL_SERVER_DB, "cluster_state", current_cluster_state)
                msg = "Cluster state changed from [%s] to [%s]" % (saved_cluster_state, current_cluster_state)
                logging.debug(msg)
                try:
                    notify_manager("{CLUSTER} {MONITOR} %s" % msg)
                except Exception, e:
                    logging.debug("Error sending notification: %s", e)
        except Exception, e:
            logging.exception("Error in monitor process: %s", e)
            time.sleep(SLEEP_ON_ERR)


if __name__ == '__main__':
    serve_forever()
