# Copyright (C) 2006-2011 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

from agent import OVSOCFS2Extension


def ocfs2_file_lookup(device, filename):
    """
    @return         Zero on success.
                    OCFS2_ET_FILE_NOT_FOUND (-1512559333L) on failure.
    """
    fs = OVSOCFS2Extension.open(device)
    try:
        return OVSOCFS2Extension.lookup(fs, filename)
    finally:
        OVSOCFS2Extension.close(fs)

def ocfs2_file_read(device, filename):
    """
    @return     File contents as a string.
                Raises an exception on failure.
    """
    fs = OVSOCFS2Extension.open(device)
    try:
        return OVSOCFS2Extension.file_read(fs, filename)
    finally:
        OVSOCFS2Extension.close(fs)

def ocfs2_file_write(device, filename, buf):
    """
    @return     Zero. Raises an exception on failure.
    """
    fs = OVSOCFS2Extension.open(device)
    try:
        return OVSOCFS2Extension.file_write(fs, filename, buf)
    finally:
        OVSOCFS2Extension.close(fs)

def ocfs2_file_remove(device, filename):
    """
    @return     Zero. Raises an exception on failure.
    """
    fs = OVSOCFS2Extension.open(device)
    try:
        return OVSOCFS2Extension.file_remove(fs, filename)
    finally:
        OVSOCFS2Extension.close(fs)
