# Copyright (C) 2006-2011 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

from agent.base import Agent


class PoolFilesystem(Agent):
    """
    Class for pool filesystem management.
    """

    def discover_pool_filesystem(self):
        """
        Discover information about the pool filesystem.

        @return: Discovery data as an XML document, or an empty document
        if no pool filesystem found.

        @raise IModuleException: on failure
        
        """
        raise NotImplementedError()

    def create_pool_filesystem(self, poolfs_type, poolfs_target, cluster_name,
            poolfs_uuid, poolfs_nfsbase_uuid, manager_uuid, pool_uuid,
            block_size="4K", cluster_size="4K", journal_size="4M"):
        """
        Create a pool filesystem.

        @param poolfs_type: the type of pool filesystem, either C{'nfs'}
        or C{'lun'}
        @type  poolfs_type: C{str}
        
        @param poolfs_target: physical location of the pool filesystem, either
        a NFS resource or a LUN device path.
        @type  poolfs_target: C{str}
        
        @param cluster_name: name of the cluster to use the pool filesystem with
        @type  cluster_name: C{str}
        
        @param poolfs_uuid: a unique identifier for the pool filesystem
        @type  poolfs_uuid: C{str}
        
        @param poolfs_nfsbase_uuid: a unique identifier for the base NFS
        filesystem
        @type  poolfs_nfsbase_uuid: C{str}
        
        @param manager_uuid: a unique identifier of the manager
        @type  manager_uuid:  C{str}
        
        @param pool_uuid: a unique identifier for the server pool
        @type  pool_uuid: C{str}
        
        @param block_size: block size of the pool filesystem
        @type  block_size: C{str}
        
        @param cluster_size: cluster size of the pool filesystem
        @type  cluster_size: C{str}
        
        @param journal_size: journal size of the pool filesystem
        @type  journal_size: C{str}

        @raise IModuleException: on failure

        """
        raise NotImplementedError()

    def destroy_pool_filesystem(self, poolfs_type, poolfs_target, poolfs_uuid,
                                poolfs_nfsbase_uuid):
        """
        Destroy a pool filesystem.

        @param poolfs_type: the type of pool filesystem, either C{'nfs'}
        or C{'lun'}
        @type  poolfs_type: C{str}

        @param poolfs_target: physical location of the pool filesystem, either
        a NFS resource or a LUN device path.
        @type  poolfs_target: C{str}

        @param poolfs_uuid: a unique identifier for the pool filesystem
        @type  poolfs_uuid: C{str}

        @param poolfs_nfsbase_uuid: a unique identifier for the base NFS
        filesystem
        @type  poolfs_nfsbase_uuid: C{str}

        @raise IModuleException: on failure

        """
        raise NotImplementedError()

    def ocfs2_get_meta_data(self, device, filename):
        """
        Get metadata stored in a file on a specific device.

        @param device: the device where the file is stored
        @type  device: C{str}

        @param filename: the name of the file containing the metadata
        @type  filename: C{str}

        @return: the metadata as a dictionary
        @rtype: C{dict}
        
        @raise IModuleException: on failure

        """
        raise NotImplementedError()
