# Copyright (C) 2006-2011 Oracle. All rights reserved.
#
# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation, version 2.  This program is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the GNU
# General Public License along with this program; if not, write to the Free
# Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
# 021110-1307, USA.

from agent.base import Agent


class RemoteManagement(Agent):
    """
    Class for remote server management.
    """

    def sys_shutdown(self):
        """
        Shutdown the server.

        @raise IModuleException: on failure

        """
        raise NotImplementedError()


    def sys_reboot(self):
        """
        Reboot the server.

        @raise IModuleException: on failure

        """
        raise NotImplementedError()


    def remote_power_off(self, controller_type, tgt_host, bmc_username="",
                         bmc_password=""):
        """
        Power off a server.
        
        @param controller_type: the mechanism to use for executing the
        power off request: C{'IPMI'} for IPMI
        @type  controller_type: C{str}
        
        @param tgt_host: for IPMI, an IP address where to send the power
        off request
        @type  tgt_host: C{str}
        
        @param bmc_username: a username for controlling the target host
        @type  bmc_username: C{str}
        
        @param bmc_password: a password for controlling the target host
        @type  bmc_password: C{str}

        @raise IModuleException: on failure

        """
        raise NotImplementedError()


    def remote_power_on(self, controller_type, tgt, arg1="", arg2=""):
        """
        Power on a server.

        @param controller_type: the mechanism to use for executing the
        power on request: C{'IPMI'} for IPMI, C{'WOL'}
        for Wake-on-LAN (WOL)
        @type  controller_type: C{str}

        @param tgt: for IPMI, an IP address where to send the power
        on request; for WOL, a MAC address for the system to power on
        @type  tgt: C{str}

        @param arg1: for IPMI, a username for controlling the target host;
        for WOL, the network device to use for sending the WOL request
        @type  arg1: C{str}

        @param arg2: for IPMI, a password for controlling the target host;
        for WOL, this parameter is not used
        @type  arg2: C{str}
        
        @raise IModuleException: on failure

        """
        raise NotImplementedError()
